@@ -21,10 +21,6 @@
 #include "config.h"
 #endif
 
-#include <exo/exo.h>
-
-#include <libxfce4ui/libxfce4ui.h>
-
 #include "thunar/thunar-abstract-dialog.h"
 #include "thunar/thunar-column-editor.h"
 #include "thunar/thunar-dialogs.h"
@@ -33,23 +29,34 @@
 #include "thunar/thunar-preferences.h"
 #include "thunar/thunar-private.h"
 
+#include <exo/exo.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 
-static void thunar_column_editor_finalize           (GObject                  *object);
-static void thunar_column_editor_help_clicked       (ThunarColumnEditor       *column_editor,
-                                                     GtkWidget                *button);
-static void thunar_column_editor_move_down          (ThunarColumnEditor       *column_editor,
-                                                     GtkWidget                *button);
-static void thunar_column_editor_move_up            (ThunarColumnEditor       *column_editor,
-                                                     GtkWidget                *button);
-static void thunar_column_editor_toggled            (ThunarColumnEditor       *column_editor,
-                                                     const gchar              *path_string,
-                                                     GtkCellRendererToggle    *cell_renderer);
-static void thunar_column_editor_toggle_visibility  (ThunarColumnEditor       *column_editor,
-                                                     GtkWidget                *button);
-static void thunar_column_editor_update_buttons     (ThunarColumnEditor       *column_editor);
-static void thunar_column_editor_use_defaults       (ThunarColumnEditor       *column_editor,
-                                                     GtkWidget                *button);
+
+static void
+thunar_column_editor_finalize (GObject *object);
+static void
+thunar_column_editor_help_clicked (ThunarColumnEditor *column_editor,
+                                   GtkWidget          *button);
+static void
+thunar_column_editor_move_down (ThunarColumnEditor *column_editor,
+                                GtkWidget          *button);
+static void
+thunar_column_editor_move_up (ThunarColumnEditor *column_editor,
+                              GtkWidget          *button);
+static void
+thunar_column_editor_toggled (ThunarColumnEditor    *column_editor,
+                              const gchar           *path_string,
+                              GtkCellRendererToggle *cell_renderer);
+static void
+thunar_column_editor_toggle_visibility (ThunarColumnEditor *column_editor,
+                                        GtkWidget          *button);
+static void
+thunar_column_editor_update_buttons (ThunarColumnEditor *column_editor);
+static void
+thunar_column_editor_use_defaults (ThunarColumnEditor *column_editor,
+                                   GtkWidget          *button);
 
 
 
@@ -65,13 +72,12 @@ struct _ThunarColumnEditor
   ThunarPreferences *preferences;
 
   ThunarColumnModel *column_model;
-  GtkTreeModelFilter *filter;
 
-  GtkWidget         *tree_view;
-  GtkWidget         *up_button;
-  GtkWidget         *down_button;
-  GtkWidget         *show_button;
-  GtkWidget         *hide_button;
+  GtkWidget *tree_view;
+  GtkWidget *up_button;
+  GtkWidget *down_button;
+  GtkWidget *show_button;
+  GtkWidget *hide_button;
 };
 
 
@@ -91,40 +97,12 @@ thunar_column_editor_class_init (ThunarColumnEditorClass *klass)
 
 
 
-static gboolean
-thunar_column_visible_func (GtkTreeModel *model,
-                            GtkTreeIter  *iter,
-                            gpointer     data)
-{
-  gchar       *col_name;
-  const gchar *del_date_col_name;
-  gboolean     visible = TRUE;
-
-  /* fetching Date Deleted column name */
-  del_date_col_name = thunar_column_model_get_column_name (THUNAR_COLUMN_MODEL (model),
-                                                           THUNAR_COLUMN_DATE_DELETED);
-
-  /* fetching iter column name */
-  gtk_tree_model_get (model, iter, THUNAR_COLUMN_MODEL_COLUMN_NAME, &col_name, -1);
-
-  /* matching iter column name & Date Deleted column name */
-  if (g_strcmp0 (col_name, del_date_col_name) == 0)
-    visible = FALSE;
-
-  g_free (col_name);
-
-  return visible;
-}
-
-
-
 static void
 thunar_column_editor_init (ThunarColumnEditor *column_editor)
 {
   GtkTreeViewColumn *column;
   GtkTreeSelection  *selection;
   GtkCellRenderer   *renderer;
-  GtkTreeIter        childIter;
   GtkTreeIter        iter;
   GtkWidget         *separator;
   GtkWidget         *button;
@@ -148,12 +126,6 @@ thunar_column_editor_init (ThunarColumnEditor *column_editor)
   g_signal_connect_data (G_OBJECT (column_editor->column_model), "rows-reordered", G_CALLBACK (thunar_column_editor_update_buttons),
                          column_editor, NULL, G_CONNECT_AFTER | G_CONNECT_SWAPPED);
 
-  /* create a filter from the shared column model */
-  column_editor->filter = GTK_TREE_MODEL_FILTER (gtk_tree_model_filter_new (GTK_TREE_MODEL (column_editor->column_model), NULL));
-  gtk_tree_model_filter_set_visible_func (column_editor->filter,
-                                          (GtkTreeModelFilterVisibleFunc) thunar_column_visible_func,
-                                          NULL, NULL);
-
   /* setup the dialog */
   gtk_dialog_add_button (GTK_DIALOG (column_editor), _("_Close"), GTK_RESPONSE_CLOSE);
   gtk_dialog_set_default_response (GTK_DIALOG (column_editor), GTK_RESPONSE_CLOSE);
@@ -208,8 +180,9 @@ thunar_column_editor_init (ThunarColumnEditor *column_editor)
   gtk_widget_show (swin);
 
   /* create the tree view */
-  column_editor->tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (column_editor->filter));
+  column_editor->tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (column_editor->column_model));
   gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (column_editor->tree_view), FALSE);
+  gtk_tree_view_set_tooltip_column (GTK_TREE_VIEW (column_editor->tree_view), THUNAR_COLUMN_MODEL_COLUMN_TOOLTIP);
   gtk_container_add (GTK_CONTAINER (swin), column_editor->tree_view);
   gtk_widget_show (column_editor->tree_view);
 
@@ -384,13 +357,8 @@ thunar_column_editor_init (ThunarColumnEditor *column_editor)
   g_signal_connect_swapped (G_OBJECT (selection), "changed", G_CALLBACK (thunar_column_editor_update_buttons), column_editor);
 
   /* select the first item */
-  if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (column_editor->column_model), &childIter))
-    {
-      /* tree_view is created from filter & column_model is the child of filter
-       * hence, child Iter needs to be converted to parent Iter */
-      gtk_tree_model_filter_convert_child_iter_to_iter (column_editor->filter, &iter, &childIter);
-      gtk_tree_selection_select_iter (selection, &iter);
-    }
+  if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (column_editor->column_model), &iter))
+    gtk_tree_selection_select_iter (selection, &iter);
 
   /* grab focus to the tree view */
   gtk_widget_grab_focus (column_editor->tree_view);
@@ -437,11 +405,8 @@ thunar_column_editor_move_down (ThunarColumnEditor *column_editor,
 {
   GtkTreeSelection *selection;
   GtkTreeModel     *model;
-  GtkTreeModel     *childModel;
   GtkTreeIter       iter1;
   GtkTreeIter       iter2;
-  GtkTreeIter       childIter1;
-  GtkTreeIter       childIter2;
 
   _thunar_return_if_fail (THUNAR_IS_COLUMN_EDITOR (column_editor));
   _thunar_return_if_fail (GTK_IS_BUTTON (button));
@@ -455,14 +420,7 @@ thunar_column_editor_move_down (ThunarColumnEditor *column_editor,
 
       /* determine the next iterator and exchange the rows */
       if (gtk_tree_model_iter_next (model, &iter2))
-        {
-          /* tree view's model is made from GTK_TREE_MODEL_FILTER, hence fetching child model and child iter's */
-          gtk_tree_model_filter_convert_iter_to_child_iter (GTK_TREE_MODEL_FILTER (model), &childIter1, &iter1);
-          gtk_tree_model_filter_convert_iter_to_child_iter (GTK_TREE_MODEL_FILTER (model), &childIter2, &iter2);
-          childModel = gtk_tree_model_filter_get_model(GTK_TREE_MODEL_FILTER (model));
-
-          thunar_column_model_exchange (THUNAR_COLUMN_MODEL (childModel), &childIter1, &childIter2);
-        }
+        thunar_column_model_exchange (THUNAR_COLUMN_MODEL (model), &iter1, &iter2);
     }
 }
 
@@ -474,12 +432,9 @@ thunar_column_editor_move_up (ThunarColumnEditor *column_editor,
 {
   GtkTreeSelection *selection;
   GtkTreeModel     *model;
-  GtkTreeModel     *childModel;
   GtkTreePath      *path;
   GtkTreeIter       iter1;
   GtkTreeIter       iter2;
-  GtkTreeIter       childIter1;
-  GtkTreeIter       childIter2;
 
   _thunar_return_if_fail (THUNAR_IS_COLUMN_EDITOR (column_editor));
   _thunar_return_if_fail (GTK_IS_BUTTON (button));
@@ -495,13 +450,8 @@ thunar_column_editor_move_up (ThunarColumnEditor *column_editor,
           /* advance to the prev path */
           if (gtk_tree_path_prev (path) && gtk_tree_model_get_iter (model, &iter2, path))
             {
-              /* tree view's model is made from GTK_TREE_MODEL_FILTER, hence fetching child model and child iter's */
-              gtk_tree_model_filter_convert_iter_to_child_iter (GTK_TREE_MODEL_FILTER (model), &childIter1, &iter1);
-              gtk_tree_model_filter_convert_iter_to_child_iter (GTK_TREE_MODEL_FILTER (model), &childIter2, &iter2);
-              childModel = gtk_tree_model_filter_get_model(GTK_TREE_MODEL_FILTER (model));
-
               /* exchange the rows */
-              thunar_column_model_exchange (THUNAR_COLUMN_MODEL (childModel), &childIter1, &childIter2);
+              thunar_column_model_exchange (THUNAR_COLUMN_MODEL (model), &iter1, &iter2);
             }
 
           /* release the path */
@@ -520,7 +470,6 @@ thunar_column_editor_toggled (ThunarColumnEditor    *column_editor,
   ThunarColumn column;
   GtkTreePath *path;
   GtkTreeIter  iter;
-  GtkTreeIter  child_iter;
   gboolean     visible;
 
   _thunar_return_if_fail (GTK_IS_CELL_RENDERER_TOGGLE (cell_renderer));
@@ -529,12 +478,10 @@ thunar_column_editor_toggled (ThunarColumnEditor    *column_editor,
 
   /* determine the tree path for the string */
   path = gtk_tree_path_new_from_string (path_string);
-  if (gtk_tree_model_get_iter (GTK_TREE_MODEL (column_editor->filter), &iter, path))
+  if (gtk_tree_model_get_iter (GTK_TREE_MODEL (column_editor->column_model), &iter, path))
     {
-      gtk_tree_model_filter_convert_iter_to_child_iter (column_editor->filter, &child_iter, &iter);
-
       /* determine the column for the iterator... */
-      column = thunar_column_model_get_column_for_iter (column_editor->column_model, &child_iter);
+      column = thunar_column_model_get_column_for_iter (column_editor->column_model, &iter);
 
       /* ...determine the existing visbility setting... */
       visible = thunar_column_model_get_column_visible (column_editor->column_model, column);
@@ -553,9 +500,7 @@ thunar_column_editor_toggle_visibility (ThunarColumnEditor *column_editor,
 {
   GtkTreeSelection *selection;
   ThunarColumn      column;
-  GtkTreeModel     *model;
   GtkTreeIter       iter;
-  GtkTreeIter       childIter;
   gboolean          visible;
 
   _thunar_return_if_fail (THUNAR_IS_COLUMN_EDITOR (column_editor));
@@ -563,13 +508,10 @@ thunar_column_editor_toggle_visibility (ThunarColumnEditor *column_editor,
 
   /* determine the selected tree iterator */
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (column_editor->tree_view));
-  if (gtk_tree_selection_get_selected (selection, &model, &iter))
+  if (gtk_tree_selection_get_selected (selection, NULL, &iter))
     {
-      /* tree view's model is made from GTK_TREE_MODEL_FILTER, hence fetching child iter */
-      gtk_tree_model_filter_convert_iter_to_child_iter (GTK_TREE_MODEL_FILTER (model), &childIter, &iter);
-
       /* determine the column for the iterator... */
-      column = thunar_column_model_get_column_for_iter (column_editor->column_model, &childIter);
+      column = thunar_column_model_get_column_for_iter (column_editor->column_model, &iter);
 
       /* ...determine the existing visbility setting... */
       visible = thunar_column_model_get_column_visible (column_editor->column_model, column);
@@ -588,9 +530,9 @@ thunar_column_editor_update_buttons (ThunarColumnEditor *column_editor)
   GtkTreeModel     *model;
   GtkTreePath      *path;
   GtkTreeIter       iter;
-  gboolean          mutable;
-  gboolean          visible;
-  gint              idx;
+  gboolean mutable;
+  gboolean visible;
+  gint     idx;
 
   /* determine the selected row */
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (column_editor->tree_view));
@@ -631,15 +573,14 @@ static void
 thunar_column_editor_use_defaults (ThunarColumnEditor *column_editor,
                                    GtkWidget          *button)
 {
-  static const gchar *PROPERTY_NAMES[] =
-  {
+  static const gchar *PROPERTY_NAMES[] = {
     "last-details-view-column-order",
     "last-details-view-visible-columns",
   };
 
   GtkTreeSelection *selection;
   GParamSpec       *pspec;
-  GValue            value = { 0, };
+  GValue            value = G_VALUE_INIT;
   guint             n;
 
   /* reset the given properties to its default values */
@@ -724,4 +665,3 @@ thunar_show_column_editor (gpointer parent)
   /* required in case of shortcut activation, in order to signal that the accel key got handled */
   return TRUE;
 }
-
