@@ -27,20 +27,25 @@ G_BEGIN_DECLS;
 typedef struct _ThunarLocationBarClass ThunarLocationBarClass;
 typedef struct _ThunarLocationBar      ThunarLocationBar;
 
-#define THUNAR_TYPE_LOCATION_BAR            (thunar_location_bar_get_type ())
-#define THUNAR_LOCATION_BAR(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), THUNAR_TYPE_LOCATION_BAR, ThunarLocationBar))
-#define THUNAR_IS_LOCATION_BAR(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), THUNAR_TYPE_LOCATION_BAR))
-#define THUNAR_LOCATION_BAR_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), THUNAR_TYPE_LOCATION_BAR, ThunarLocationBarClass))
+#define THUNAR_TYPE_LOCATION_BAR (thunar_location_bar_get_type ())
+#define THUNAR_LOCATION_BAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), THUNAR_TYPE_LOCATION_BAR, ThunarLocationBar))
+#define THUNAR_IS_LOCATION_BAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), THUNAR_TYPE_LOCATION_BAR))
+#define THUNAR_LOCATION_BAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), THUNAR_TYPE_LOCATION_BAR, ThunarLocationBarClass))
 
 
-GType      thunar_location_bar_get_type         (void) G_GNUC_CONST;
+GType
+thunar_location_bar_get_type (void) G_GNUC_CONST;
 
-GtkWidget *thunar_location_bar_new              (void);
-void       thunar_location_bar_request_entry    (ThunarLocationBar *bar,
-                                                 const gchar       *initial_text,
-                                                 gboolean           temporary_till_focus_lost);
-void       thunar_location_bar_cancel_search    (ThunarLocationBar *bar);
-gchar*     thunar_location_bar_get_search_query (ThunarLocationBar *entry);
+GtkWidget *
+thunar_location_bar_new (void);
+void
+thunar_location_bar_request_entry (ThunarLocationBar *bar,
+                                   const gchar       *initial_text,
+                                   gboolean           temporary_till_focus_lost);
+void
+thunar_location_bar_cancel_search (ThunarLocationBar *bar);
+gchar *
+thunar_location_bar_get_search_query (ThunarLocationBar *entry);
 
 G_END_DECLS;
 
