@@ -33,8 +33,6 @@
 #include <unistd.h>
 #endif
 
-#include <exo/exo.h>
-
 #include "thunar/thunar-dialogs.h"
 #include "thunar/thunar-enum-types.h"
 #include "thunar/thunar-gobject-extensions.h"
@@ -46,6 +44,7 @@
 #include "thunar/thunar-private.h"
 #include "thunar/thunar-user.h"
 
+#include <exo/exo.h>
 #include <libxfce4ui/libxfce4ui.h>
 
 
@@ -75,54 +74,74 @@ enum
 
 
 
-static void                 thunar_permissions_chooser_finalize         (GObject                        *object);
-static void                 thunar_permissions_chooser_get_property     (GObject                        *object,
-                                                                         guint                           prop_id,
-                                                                         GValue                         *value,
-                                                                         GParamSpec                     *pspec);
-static void                 thunar_permissions_chooser_set_property     (GObject                        *object,
-                                                                         guint                           prop_id,
-                                                                         const GValue                   *value,
-                                                                         GParamSpec                     *pspec);
-static gint                 thunar_permissions_chooser_ask_recursive    (ThunarPermissionsChooser       *chooser);
-static void                 thunar_permissions_chooser_change_group     (ThunarPermissionsChooser       *chooser,
-                                                                         guint32                         gid);
-static gboolean             thunar_permissions_chooser_change_mode      (ThunarPermissionsChooser       *chooser,
-                                                                         ThunarFileMode                  dir_mask,
-                                                                         ThunarFileMode                  dir_mode,
-                                                                         ThunarFileMode                  file_mask,
-                                                                         ThunarFileMode                  file_mode);
-static void                 thunar_permissions_chooser_access_changed   (ThunarPermissionsChooser       *chooser,
-                                                                         GtkWidget                      *combo);
-static void                 thunar_permissions_chooser_file_changed     (ThunarPermissionsChooser       *chooser);
-static void                 thunar_permissions_chooser_group_changed    (ThunarPermissionsChooser       *chooser,
-                                                                         GtkWidget                      *combo);
-static void                 thunar_permissions_chooser_program_toggled  (ThunarPermissionsChooser       *chooser,
-                                                                         GtkWidget                      *button);
-static void                 thunar_permissions_chooser_fixperm_clicked  (ThunarPermissionsChooser       *chooser,
-                                                                         GtkWidget                      *button);
-static ThunarJobResponse    thunar_permissions_chooser_job_ask          (ThunarPermissionsChooser       *chooser,
-                                                                         const gchar                    *message,
-                                                                         ThunarJobResponse               choices,
-                                                                         ThunarJob                      *job);
-static void                 thunar_permissions_chooser_job_cancel       (ThunarPermissionsChooser       *chooser);
-static void                 thunar_permissions_chooser_job_error        (ThunarPermissionsChooser       *chooser,
-                                                                         GError                         *error,
-                                                                         ThunarJob                      *job);
-static void                 thunar_permissions_chooser_job_finished     (ThunarPermissionsChooser       *chooser,
-                                                                         ThunarJob                      *job);
-static void                 thunar_permissions_chooser_job_percent      (ThunarPermissionsChooser       *chooser,
-                                                                         gdouble                         percent,
-                                                                         ThunarJob                      *job);
-static void                 thunar_permissions_chooser_job_start        (ThunarPermissionsChooser       *chooser,
-                                                                         ThunarJob                      *job,
-                                                                         gboolean                        recursive);
-static gboolean             thunar_permissions_chooser_row_separator    (GtkTreeModel                   *model,
-                                                                         GtkTreeIter                    *iter,
-                                                                         gpointer                        data);
-static GList               *thunar_permissions_chooser_get_files        (ThunarPermissionsChooser       *chooser);
-static void                 thunar_permissions_chooser_set_files        (ThunarPermissionsChooser       *chooser,
-                                                                         GList                          *files);
+static void
+thunar_permissions_chooser_finalize (GObject *object);
+static void
+thunar_permissions_chooser_get_property (GObject    *object,
+                                         guint       prop_id,
+                                         GValue     *value,
+                                         GParamSpec *pspec);
+static void
+thunar_permissions_chooser_set_property (GObject      *object,
+                                         guint         prop_id,
+                                         const GValue *value,
+                                         GParamSpec   *pspec);
+static gint
+thunar_permissions_chooser_ask_recursive (ThunarPermissionsChooser *chooser);
+static void
+thunar_permissions_chooser_change_group (ThunarPermissionsChooser *chooser,
+                                         guint32                   gid);
+static gboolean
+thunar_permissions_chooser_change_mode (ThunarPermissionsChooser *chooser,
+                                        ThunarFileMode            dir_mask,
+                                        ThunarFileMode            dir_mode,
+                                        ThunarFileMode            file_mask,
+                                        ThunarFileMode            file_mode);
+static void
+thunar_permissions_chooser_access_changed (ThunarPermissionsChooser *chooser,
+                                           GtkWidget                *combo);
+static void
+thunar_permissions_chooser_file_changed (ThunarPermissionsChooser *chooser);
+static void
+thunar_permissions_chooser_group_changed (ThunarPermissionsChooser *chooser,
+                                          GtkWidget                *combo);
+static void
+thunar_permissions_chooser_program_toggled (ThunarPermissionsChooser *chooser,
+                                            GtkWidget                *button);
+static void
+thunar_permissions_chooser_fixperm_clicked (ThunarPermissionsChooser *chooser,
+                                            GtkWidget                *button);
+static ThunarJobResponse
+thunar_permissions_chooser_job_ask (ThunarPermissionsChooser *chooser,
+                                    const gchar              *message,
+                                    ThunarJobResponse         choices,
+                                    ThunarJob                *job);
+static void
+thunar_permissions_chooser_job_cancel (ThunarPermissionsChooser *chooser);
+static void
+thunar_permissions_chooser_job_error (ThunarPermissionsChooser *chooser,
+                                      GError                   *error,
+                                      ThunarJob                *job);
+static void
+thunar_permissions_chooser_job_finished (ThunarPermissionsChooser *chooser,
+                                         ThunarJob                *job);
+static void
+thunar_permissions_chooser_job_percent (ThunarPermissionsChooser *chooser,
+                                        gdouble                   percent,
+                                        ThunarJob                *job);
+static void
+thunar_permissions_chooser_job_start (ThunarPermissionsChooser *chooser,
+                                      ThunarJob                *job,
+                                      gboolean                  recursive);
+static gboolean
+thunar_permissions_chooser_row_separator (GtkTreeModel *model,
+                                          GtkTreeIter  *iter,
+                                          gpointer      data);
+static GList *
+thunar_permissions_chooser_get_files (ThunarPermissionsChooser *chooser);
+static void
+thunar_permissions_chooser_set_files (ThunarPermissionsChooser *chooser,
+                                      GList                    *files);
 
 
 struct _ThunarPermissionsChooserClass
@@ -132,23 +151,23 @@ struct _ThunarPermissionsChooserClass
 
 struct _ThunarPermissionsChooser
 {
-  GtkVBox     __parent__;
+  GtkVBox __parent__;
 
-  GList      *files;
+  GList *files;
 
   /* the main grid widget, which contains everything but the job control stuff */
-  GtkWidget  *grid;
+  GtkWidget *grid;
 
-  GtkWidget  *user_label;
-  GtkWidget  *group_combo;
-  GtkWidget  *access_combos[3];
-  GtkWidget  *program_button;
-  GtkWidget  *fixperm_label;
-  GtkWidget  *fixperm_button;
+  GtkWidget *user_label;
+  GtkWidget *group_combo;
+  GtkWidget *access_combos[3];
+  GtkWidget *program_button;
+  GtkWidget *fixperm_label;
+  GtkWidget *fixperm_button;
 
   /* job control stuff */
-  ThunarJob  *job;
-  GtkWidget  *job_progress;
+  ThunarJob *job;
+  GtkWidget *job_progress;
 };
 
 
@@ -249,7 +268,7 @@ thunar_permissions_chooser_init (ThunarPermissionsChooser *chooser)
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), chooser->access_combos[2]);
   gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (chooser->access_combos[2]), renderer_text, TRUE);
   gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (chooser->access_combos[2]), renderer_text, "text", 0);
-  g_object_bind_property (G_OBJECT (chooser),                   "mutable",
+  g_object_bind_property (G_OBJECT (chooser), "mutable",
                           G_OBJECT (chooser->access_combos[2]), "sensitive",
                           G_BINDING_SYNC_CREATE);
   g_signal_connect_swapped (G_OBJECT (chooser->access_combos[2]), "changed", G_CALLBACK (thunar_permissions_chooser_access_changed), chooser);
@@ -278,7 +297,7 @@ thunar_permissions_chooser_init (ThunarPermissionsChooser *chooser)
   gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (chooser->group_combo), renderer_text, TRUE);
   gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (chooser->group_combo), renderer_text, "text", THUNAR_PERMISSIONS_STORE_COLUMN_NAME);
   gtk_combo_box_set_row_separator_func (GTK_COMBO_BOX (chooser->group_combo), thunar_permissions_chooser_row_separator, NULL, NULL);
-  g_object_bind_property (G_OBJECT (chooser),              "mutable",
+  g_object_bind_property (G_OBJECT (chooser), "mutable",
                           G_OBJECT (chooser->group_combo), "sensitive",
                           G_BINDING_SYNC_CREATE);
   g_signal_connect_swapped (G_OBJECT (chooser->group_combo), "changed", G_CALLBACK (thunar_permissions_chooser_group_changed), chooser);
@@ -299,7 +318,7 @@ thunar_permissions_chooser_init (ThunarPermissionsChooser *chooser)
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), chooser->access_combos[1]);
   gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (chooser->access_combos[1]), renderer_text, TRUE);
   gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (chooser->access_combos[1]), renderer_text, "text", 0);
-  g_object_bind_property (G_OBJECT (chooser),                   "mutable",
+  g_object_bind_property (G_OBJECT (chooser), "mutable",
                           G_OBJECT (chooser->access_combos[1]), "sensitive",
                           G_BINDING_SYNC_CREATE);
   g_signal_connect_swapped (G_OBJECT (chooser->access_combos[1]), "changed", G_CALLBACK (thunar_permissions_chooser_access_changed), chooser);
@@ -335,7 +354,7 @@ thunar_permissions_chooser_init (ThunarPermissionsChooser *chooser)
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), chooser->access_combos[0]);
   gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (chooser->access_combos[0]), renderer_text, TRUE);
   gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (chooser->access_combos[0]), renderer_text, "text", 0);
-  g_object_bind_property (G_OBJECT (chooser),                   "mutable",
+  g_object_bind_property (G_OBJECT (chooser), "mutable",
                           G_OBJECT (chooser->access_combos[0]), "sensitive",
                           G_BINDING_SYNC_CREATE);
   g_signal_connect_swapped (G_OBJECT (chooser->access_combos[0]), "changed", G_CALLBACK (thunar_permissions_chooser_access_changed), chooser);
@@ -361,9 +380,9 @@ thunar_permissions_chooser_init (ThunarPermissionsChooser *chooser)
 
   chooser->program_button = gtk_check_button_new_with_mnemonic (_("Allow this file to _run as a program"));
   g_object_bind_property (G_OBJECT (chooser->program_button), "visible",
-                          G_OBJECT (label),                   "visible",
+                          G_OBJECT (label), "visible",
                           G_BINDING_SYNC_CREATE);
-  g_object_bind_property (G_OBJECT (chooser),                 "mutable",
+  g_object_bind_property (G_OBJECT (chooser), "mutable",
                           G_OBJECT (chooser->program_button), "sensitive",
                           G_BINDING_SYNC_CREATE);
   g_signal_connect_swapped (G_OBJECT (chooser->program_button), "toggled", G_CALLBACK (thunar_permissions_chooser_program_toggled), chooser);
@@ -375,10 +394,10 @@ thunar_permissions_chooser_init (ThunarPermissionsChooser *chooser)
 
   hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
   g_object_bind_property (G_OBJECT (chooser), "mutable",
-                          G_OBJECT (hbox),    "sensitive",
+                          G_OBJECT (hbox), "sensitive",
                           G_BINDING_SYNC_CREATE);
   g_object_bind_property (G_OBJECT (chooser->program_button), "visible",
-                          G_OBJECT (hbox),                    "visible",
+                          G_OBJECT (hbox), "visible",
                           G_BINDING_SYNC_CREATE);
   gtk_grid_attach (GTK_GRID (chooser->grid), hbox, 1, row, 1, 1);
   gtk_widget_show (hbox);
@@ -396,7 +415,7 @@ thunar_permissions_chooser_init (ThunarPermissionsChooser *chooser)
 
   hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
   g_object_bind_property (G_OBJECT (chooser), "mutable",
-                          G_OBJECT (hbox),    "sensitive",
+                          G_OBJECT (hbox), "sensitive",
                           G_BINDING_SYNC_CREATE);
   gtk_grid_attach (GTK_GRID (chooser->grid), hbox, 1, row, 1, 1);
   gtk_widget_show (hbox);
@@ -410,7 +429,7 @@ thunar_permissions_chooser_init (ThunarPermissionsChooser *chooser)
   gtk_label_set_attributes (GTK_LABEL (chooser->fixperm_label), thunar_pango_attr_list_small_italic ());
   gtk_label_set_line_wrap (GTK_LABEL (chooser->fixperm_label), TRUE);
   g_object_bind_property (G_OBJECT (chooser->fixperm_label), "visible",
-                          G_OBJECT (hbox),                   "visible",
+                          G_OBJECT (hbox), "visible",
                           G_BINDING_SYNC_CREATE);
   gtk_box_pack_start (GTK_BOX (hbox), chooser->fixperm_label, TRUE, TRUE, 0);
   gtk_widget_show (chooser->fixperm_label);
@@ -558,9 +577,9 @@ thunar_permissions_chooser_ask_recursive (ThunarPermissionsChooser *chooser)
       dialog = gtk_dialog_new_with_buttons (_("Question"), GTK_WINDOW (toplevel),
                                             GTK_DIALOG_DESTROY_WITH_PARENT
                                             | GTK_DIALOG_MODAL,
-                                            _("_Cancel"), GTK_RESPONSE_CANCEL,
-                                            _("_No"), GTK_RESPONSE_NO,
-                                            _("_Yes"), GTK_RESPONSE_YES,
+                                              _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                                _("_No"), GTK_RESPONSE_NO,
+                                                  _("_Yes"), GTK_RESPONSE_YES,
                                             NULL);
       gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_YES);
 
@@ -726,7 +745,7 @@ thunar_permissions_chooser_change_group (ThunarPermissionsChooser *chooser,
           recursive = FALSE;
           break;
 
-        default:  /* cancelled by the user */
+        default: /* cancelled by the user */
           thunar_permissions_chooser_file_changed (chooser);
           return;
         }
@@ -772,7 +791,7 @@ thunar_permissions_chooser_change_mode (ThunarPermissionsChooser *chooser,
           recursive = FALSE;
           break;
 
-        default:  /* cancelled by the user */
+        default: /* cancelled by the user */
           thunar_permissions_chooser_file_changed (chooser);
           return FALSE;
         }
@@ -795,14 +814,14 @@ static void
 thunar_permissions_chooser_access_changed (ThunarPermissionsChooser *chooser,
                                            GtkWidget                *combo)
 {
-  ThunarFileMode  file_mask;
-  ThunarFileMode  file_mode;
-  ThunarFileMode  dir_mask;
-  ThunarFileMode  dir_mode;
-  guint           n;
-  gint            active_mode;
-  GtkTreeModel   *model;
-  GtkTreeIter     iter;
+  ThunarFileMode file_mask;
+  ThunarFileMode file_mode;
+  ThunarFileMode dir_mask;
+  ThunarFileMode dir_mode;
+  guint          n;
+  gint           active_mode;
+  GtkTreeModel  *model;
+  GtkTreeIter    iter;
 
   _thunar_return_if_fail (THUNAR_IS_PERMISSIONS_CHOOSER (chooser));
   _thunar_return_if_fail (GTK_IS_COMBO_BOX (combo));
@@ -813,7 +832,8 @@ thunar_permissions_chooser_access_changed (ThunarPermissionsChooser *chooser,
     return;
 
   /* determine the new mode from the combo box */
-  for (n = 0; n < G_N_ELEMENTS (chooser->access_combos) && chooser->access_combos[n] != combo ; ++n);
+  for (n = 0; n < G_N_ELEMENTS (chooser->access_combos) && chooser->access_combos[n] != combo; ++n)
+    ;
   dir_mode = file_mode = (active_mode << 1) << (n * 3);
   dir_mask = file_mask = 0006 << (n * 3);
 
@@ -891,9 +911,11 @@ thunar_permissions_chooser_file_changed (ThunarPermissionsChooser *chooser)
   gchar              buffer[1024];
   guint              n;
   guint              n_files = 0;
-  gint               modes[3] = { 0, };
-  gint               file_modes[3];
-  GtkListStore      *access_store;
+  gint               modes[3] = {
+    0,
+  };
+  gint          file_modes[3];
+  GtkListStore *access_store;
 
   _thunar_return_if_fail (THUNAR_IS_PERMISSIONS_CHOOSER (chooser));
 
@@ -980,7 +1002,7 @@ thunar_permissions_chooser_file_changed (ThunarPermissionsChooser *chooser)
       if (G_LIKELY (user != NULL))
         {
           groups = g_list_copy (thunar_user_get_groups (user));
-          g_list_foreach (groups, (GFunc) (void (*)(void)) g_object_ref, NULL);
+          g_list_foreach (groups, (GFunc) (void (*) (void)) g_object_ref, NULL);
         }
     }
 
@@ -1192,8 +1214,8 @@ thunar_permissions_chooser_fixperm_clicked (ThunarPermissionsChooser *chooser,
 
           /* determine the new mode (making sure the owner can read/enter the folder) */
           mode = (THUNAR_FILE_MODE_USR_READ | THUNAR_FILE_MODE_USR_EXEC)
-               | (((mode & THUNAR_FILE_MODE_GRP_READ) != 0) ? THUNAR_FILE_MODE_GRP_EXEC : 0)
-               | (((mode & THUNAR_FILE_MODE_OTH_READ) != 0) ? THUNAR_FILE_MODE_OTH_EXEC : 0);
+                 | (((mode & THUNAR_FILE_MODE_GRP_READ) != 0) ? THUNAR_FILE_MODE_GRP_EXEC : 0)
+                 | (((mode & THUNAR_FILE_MODE_OTH_READ) != 0) ? THUNAR_FILE_MODE_OTH_EXEC : 0);
 
           file_list.prev = NULL;
           file_list.data = thunar_file_get_file (THUNAR_FILE (lp->data));
@@ -1377,7 +1399,7 @@ thunar_permissions_chooser_row_separator (GtkTreeModel *model,
  *
  * Return value: the file associated with @chooser.
  **/
-GList*
+GList *
 thunar_permissions_chooser_get_files (ThunarPermissionsChooser *chooser)
 {
   _thunar_return_val_if_fail (THUNAR_IS_PERMISSIONS_CHOOSER (chooser), NULL);
@@ -1445,7 +1467,7 @@ thunar_permissions_chooser_set_files (ThunarPermissionsChooser *chooser,
  *
  * Return value: the newly allocated #ThunarPermissionsChooser.
  **/
-GtkWidget*
+GtkWidget *
 thunar_permissions_chooser_new (void)
 {
   return g_object_new (THUNAR_TYPE_PERMISSIONS_CHOOSER, NULL);
