@@ -3,6 +3,5 @@
 
 #include <gio/gio.h>
 
-extern GResource *
-thunar_get_resource (void);
+extern GResource *thunar_get_resource (void);
 #endif
