@@ -27,16 +27,18 @@ G_BEGIN_DECLS;
 typedef struct _ThunarTextRendererClass ThunarTextRendererClass;
 typedef struct _ThunarTextRenderer      ThunarTextRenderer;
 
-#define THUNAR_TYPE_TEXT_RENDERER            (thunar_text_renderer_get_type ())
-#define THUNAR_TEXT_RENDERER(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), THUNAR_TYPE_TEXT_RENDERER, ThunarTextRenderer))
-#define THUNAR_TEXT_RENDERER_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), THUNAR_TYPE_TEXT_RENDERER, ThunarTextRendererClass))
-#define THUNAR_IS_TEXT_RENDERER(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), THUNAR_TYPE_TEXT_RENDERER))
+#define THUNAR_TYPE_TEXT_RENDERER (thunar_text_renderer_get_type ())
+#define THUNAR_TEXT_RENDERER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), THUNAR_TYPE_TEXT_RENDERER, ThunarTextRenderer))
+#define THUNAR_TEXT_RENDERER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), THUNAR_TYPE_TEXT_RENDERER, ThunarTextRendererClass))
+#define THUNAR_IS_TEXT_RENDERER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), THUNAR_TYPE_TEXT_RENDERER))
 #define THUNAR_IS_TEXT_RENDERER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), THUNAR_TYPE_TEXT_RENDERER))
-#define THUNAR_TEXT_RENDERER_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), THUNAR_TYPE_TEXT_RENDERER, ThunarTextRendererClass))
+#define THUNAR_TEXT_RENDERER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), THUNAR_TYPE_TEXT_RENDERER, ThunarTextRendererClass))
 
-GType            thunar_text_renderer_get_type (void) G_GNUC_CONST;
+GType
+thunar_text_renderer_get_type (void) G_GNUC_CONST;
 
-GtkCellRenderer *thunar_text_renderer_new      (void) G_GNUC_MALLOC;
+GtkCellRenderer *
+thunar_text_renderer_new (void) G_GNUC_MALLOC;
 
 G_END_DECLS;
 
