@@ -42,23 +42,27 @@ typedef struct _ThunarTransferJobPrivate ThunarTransferJobPrivate;
 typedef struct _ThunarTransferJobClass   ThunarTransferJobClass;
 typedef struct _ThunarTransferJob        ThunarTransferJob;
 
-#define THUNAR_TYPE_TRANSFER_JOB            (thunar_transfer_job_get_type ())
-#define THUNAR_TRANSFER_JOB(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), THUNAR_TYPE_TRANSFER_JOB, ThunarTransferJob))
-#define THUNAR_TRANSFER_JOB_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), THUNAR_TYPE_TRANSFER_JOB, ThunarTransferJobClass))
-#define THUNAR_IS_TRANSFER_JOB(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), THUNAR_TYPE_TRANSFER_JOB))
+#define THUNAR_TYPE_TRANSFER_JOB (thunar_transfer_job_get_type ())
+#define THUNAR_TRANSFER_JOB(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), THUNAR_TYPE_TRANSFER_JOB, ThunarTransferJob))
+#define THUNAR_TRANSFER_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), THUNAR_TYPE_TRANSFER_JOB, ThunarTransferJobClass))
+#define THUNAR_IS_TRANSFER_JOB(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), THUNAR_TYPE_TRANSFER_JOB))
 #define THUNAR_IS_TRANSFER_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), THUNAR_TYPE_TRANSFER_JOB)
-#define THUNAR_TRANSFER_JOB_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), THUNAR_TYPE_TRANSFER_JOB, ThunarTransferJobClass))
+#define THUNAR_TRANSFER_JOB_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), THUNAR_TYPE_TRANSFER_JOB, ThunarTransferJobClass))
 
-GType      thunar_transfer_job_get_type (void) G_GNUC_CONST;
+GType
+thunar_transfer_job_get_type (void) G_GNUC_CONST;
 
-ThunarJob *thunar_transfer_job_new        (GList                *source_file_list,
-                                           GList                *target_file_list,
-                                           ThunarTransferJobType type) G_GNUC_MALLOC G_GNUC_WARN_UNUSED_RESULT;
+ThunarJob *
+thunar_transfer_job_new (GList                *source_file_list,
+                         GList                *target_file_list,
+                         ThunarTransferJobType type) G_GNUC_MALLOC G_GNUC_WARN_UNUSED_RESULT;
 
-gchar     *thunar_transfer_job_get_status (ThunarTransferJob    *job);
+gchar *
+thunar_transfer_job_get_status (ThunarTransferJob *job);
 
-gboolean   thunar_transfer_job_can_start  (ThunarTransferJob *transfer_job,
-                                           GList             *running_job_list);
+gboolean
+thunar_transfer_job_can_start (ThunarTransferJob *transfer_job,
+                               GList             *running_job_list);
 
 G_END_DECLS
 
