@@ -560,8 +560,8 @@ thunar_util_parse_parent (gpointer    parent,
     }
   else if (GDK_IS_SCREEN (parent))
     {
-      /* yep, that's a screen */
-      screen = GDK_SCREEN (parent);
+      /* A specific screen was requested. Just return it, without filling 'window_return' */
+      return GDK_SCREEN (parent);
     }
   else
     {
