@@ -25,22 +25,22 @@
 #ifndef __THUNARX_RENAMER_H__
 #define __THUNARX_RENAMER_H__
 
-#include <gtk/gtk.h>
-
 #include "thunarx/thunarx-file-info.h"
 
+#include <gtk/gtk.h>
+
 G_BEGIN_DECLS
 
 typedef struct _ThunarxRenamerPrivate ThunarxRenamerPrivate;
 typedef struct _ThunarxRenamerClass   ThunarxRenamerClass;
 typedef struct _ThunarxRenamer        ThunarxRenamer;
 
-#define THUNARX_TYPE_RENAMER            (thunarx_renamer_get_type ())
-#define THUNARX_RENAMER(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), THUNARX_TYPE_RENAMER, ThunarxRenamer))
-#define THUNARX_RENAMER_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), THUNARX_TYPE_RENAMER, ThunarxRenamerClass))
-#define THUNARX_IS_RENAMER(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), THUNARX_TYPE_RENAMER))
+#define THUNARX_TYPE_RENAMER (thunarx_renamer_get_type ())
+#define THUNARX_RENAMER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), THUNARX_TYPE_RENAMER, ThunarxRenamer))
+#define THUNARX_RENAMER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), THUNARX_TYPE_RENAMER, ThunarxRenamerClass))
+#define THUNARX_IS_RENAMER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), THUNARX_TYPE_RENAMER))
 #define THUNARX_IS_RENAMER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), THUNARX_TYPE_RENAMER))
-#define THUNARX_RENAMER_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), THUNARX_TYPE_RENAMER, ThunarxRenamerClass))
+#define THUNARX_RENAMER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), THUNARX_TYPE_RENAMER, ThunarxRenamerClass))
 
 /**
  * ThunarxRenamerClass:
@@ -64,19 +64,19 @@ struct _ThunarxRenamerClass
   /*< public >*/
 
   /* virtual methods */
-  gchar *(*process)        (ThunarxRenamer  *renamer,
-                            ThunarxFileInfo *file,
-                            const gchar     *text,
-                            guint            index);
+  gchar *(*process) (ThunarxRenamer  *renamer,
+                     ThunarxFileInfo *file,
+                     const gchar     *text,
+                     guint            index);
 
-  void   (*load)           (ThunarxRenamer  *renamer,
-                            GHashTable      *settings);
-  void   (*save)           (ThunarxRenamer  *renamer,
-                            GHashTable      *settings);
+  void (*load) (ThunarxRenamer *renamer,
+                GHashTable     *settings);
+  void (*save) (ThunarxRenamer *renamer,
+                GHashTable     *settings);
 
-  GList *(*get_menu_items) (ThunarxRenamer  *renamer,
-                            GtkWindow       *window,
-                            GList           *files);
+  GList *(*get_menu_items) (ThunarxRenamer *renamer,
+                            GtkWindow      *window,
+                            GList          *files);
 
   /*< private >*/
   void (*reserved0) (void);
@@ -104,31 +104,41 @@ struct _ThunarxRenamer
   ThunarxRenamerPrivate *priv;
 };
 
-GType        thunarx_renamer_get_type       (void) G_GNUC_CONST;
+GType
+thunarx_renamer_get_type (void) G_GNUC_CONST;
 
-const gchar *thunarx_renamer_get_help_url   (ThunarxRenamer   *renamer);
-void         thunarx_renamer_set_help_url   (ThunarxRenamer   *renamer,
-                                             const gchar      *help_url);
+const gchar *
+thunarx_renamer_get_help_url (ThunarxRenamer *renamer);
+void
+thunarx_renamer_set_help_url (ThunarxRenamer *renamer,
+                              const gchar    *help_url);
 
-const gchar *thunarx_renamer_get_name       (ThunarxRenamer   *renamer);
-void         thunarx_renamer_set_name       (ThunarxRenamer   *renamer,
-                                             const gchar      *name);
+const gchar *
+thunarx_renamer_get_name (ThunarxRenamer *renamer);
+void
+thunarx_renamer_set_name (ThunarxRenamer *renamer,
+                          const gchar    *name);
 
-gchar       *thunarx_renamer_process        (ThunarxRenamer   *renamer,
-                                             ThunarxFileInfo  *file,
-                                             const gchar      *text,
-                                             guint             index) G_GNUC_MALLOC;
+gchar *
+thunarx_renamer_process (ThunarxRenamer  *renamer,
+                         ThunarxFileInfo *file,
+                         const gchar     *text,
+                         guint            index) G_GNUC_MALLOC;
 
-void         thunarx_renamer_load           (ThunarxRenamer   *renamer,
-                                             GHashTable       *settings);
-void         thunarx_renamer_save           (ThunarxRenamer   *renamer,
-                                             GHashTable       *settings);
+void
+thunarx_renamer_load (ThunarxRenamer *renamer,
+                      GHashTable     *settings);
+void
+thunarx_renamer_save (ThunarxRenamer *renamer,
+                      GHashTable     *settings);
 
-GList       *thunarx_renamer_get_menu_items (ThunarxRenamer   *renamer,
-                                             GtkWindow        *window,
-                                             GList            *files) G_GNUC_MALLOC;
+GList *
+thunarx_renamer_get_menu_items (ThunarxRenamer *renamer,
+                                GtkWindow      *window,
+                                GList          *files) G_GNUC_MALLOC;
 
-void         thunarx_renamer_changed        (ThunarxRenamer   *renamer);
+void
+thunarx_renamer_changed (ThunarxRenamer *renamer);
 
 G_END_DECLS
 
